:github_url: https://github.com/stephane-caron/qpmpc/tree/main/doc/src/usage.rst

*****
Usage
*****

Defining an optimal control problem
===================================

.. automodule:: qpmpc.mpc_problem
    :members:

Solving the optimal control problem
===================================

.. autofunction:: qpmpc.solve_mpc.solve_mpc

Reading the solution
====================

.. automodule:: qpmpc.plan
    :members:
